<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cenzor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable cenzor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Admonition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swearwords</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exclusions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CenzorNotificationService</name>
    <message>
        <source>Cenzor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor used obscene word and became admonished</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ListEditWidget</name>
    <message>
        <source>Add</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>